%
% This file has been developed as a common template for papers destined for electronic production using Adobe Acrobat software for AYSS conferences
%

\newlength{\dsep}
\newlength{\dwid}
\newlength{\dht}

%
% Based on standard LaTeX article class need to define font size optionin side .cls file
%

\NeedsTeXFormat{LaTeX2e}

%
% Define .cls file version, filedate variables
%

\def\fileversion{2.0}
\def\filedate{21/11/2010}

\ProvidesClass{ayss_en}[\filedate \space Version \fileversion]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

%
% Set margins for a4paper if specified
%

\ProcessOptions\relax

%
% Build on standard article class
%

\LoadClass[12pt,a4paper]{article}
%\RequirePackage[english,russian]{babel}

%
% Using times fonts produces a uniform, compact document suitable for the Adobe Acrobat software and printable any where
%

\typeout{                                                                           }
\typeout{---------------------------------------------------------------------------}
\typeout{    LaTeX2e Class file for AYSS conference publication for LaTeX2e users   }
\typeout{                                                                           }
\typeout{ Use the pagewithcorrectmargins to draw a box on page with correct margins }
\typeout{                                                                           }
\typeout{    Itemize, Enumerate and Description environments are compact versions   }
\typeout{---------------------------------------------------------------------------}
\typeout{                                                                           }

%
% Set page format following based on default top and left offset
%

\setlength{\textheight}{233mm}
\setlength{\textwidth}{162mm}
\setlength{\topmargin}{12.34mm}
\setlength{\oddsidemargin}{25mm}
\pagestyle{empty}
\hoffset -25.4mm
\voffset -25.4mm

%
% Define superscript to cross reference author and affiliations
%

\def\superscript#1{\raisebox{0.8ex}{#1}\hspace{0.05em}}

%
% Prevent infinite loops
%

\let\Otemize=\itemize
\let\Onumerate=\enumerate
\let\Oescription=\description

%
% Zero the vertical spacing parameters
%

\def\Nospacing{
  \itemsep=0pt
  \topsep=0pt
  \partopsep=0pt
  \parskip=0pt
  \parsep=0pt}

%
% Redefine the environments in terms of the original values
%

\newenvironment{Itemize}{\Otemize\Nospacing}{\endlist}
\newenvironment{Enumerate}{\Onumerate\Nospacing}{\endlist}
\newenvironment{Description}{\Oescription\Nospacing}{\endlist}

\renewcommand{\topfraction}{.95}
\renewcommand{\bottomfraction}{.95}
\renewcommand{\textfraction}{0.1}
\renewcommand{\floatpagefraction}{0.8}
%\renewcommand{\baselinestretch}{1.5}

\def\@oddhead{}
\def\@evenhead{}
\def\@oddfoot{}
\def\@evenfoot{\@oddfoot}

%
% \section is tricky because we want to both support \section* and have the section title uppercased
%

\def\section{
  \secdef\@sectionb\@sections}
\def\@sectionb[#1]#2{
  \@sections{#2}}
\def\@sections#1{
  \@startsection{section}{1}{\z@}{3pt}{3pt}{\normalsize\bf\boldmath}{\uppercase{#1}}}
\def\subsection{
  \@startsection{subsection}{2}{\z@}{3pt}{3pt}{\normalsize\bf\textit}}
\def\abstract{
  \section*{ANNOTATION}}

\setcounter{secnumdepth}{0}

%
% This definition of \maketitle taken from article.sty, and has been somewhat modified
%

\def\maketitle{
  \par\begingroup
    \def\thefootnote{
      \fnsymbol{footnote}}
      \def\@makefnmark{\hbox
        to 5pt{$^{\@thefnmark}$\hss}}
      \@maketitle
      \@thanks
  \endgroup
  \setcounter{footnote}{0}
  \let\maketitle\relax
  \let\@maketitle\relax
  \gdef\@thanks{}\gdef\@author{}\gdef\@title{}\let\thanks\relax}

%
% So user can change it if need be
%

\def\@maketitle{\par
  \hsize\textwidth
  \linewidth\hsize\centering{
    \large\bf\@title\par}
   \centering{
      \@author\par}}

%
% Figure and table captions, correct caption format, replacing : with .
%

\def\@makecaption#1#2{
  \vskip\abovecaptionskip
  \sbox\@tempboxa{{\footnotesize\bf #1.\ }{\footnotesize\bf #2}}%
  \ifdim \wd\@tempboxa >\hsize
    {\footnotesize\bf #1.\ }{\footnotesize\bf #2 \par}
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}
  \fi
  \vskip\belowcaptionskip}

%
% Redefine to use smaller fonts
%

\def\thebibliography#1{
  \setlength{\itemsep}{0pt}\setlength{\parsep}{0pt}
  \section*{References\@mkboth{Bibliography}{References}}\small\list{[\arabic{enumi}]}{\settowidth\labelwidth{[#1]}
  \leftmargin\labelwidth\advance\leftmargin\labelsep\usecounter{enumi}}
\def\newblock{\hskip .11em plus .33em minus .07em}
  \sloppy\clubpenalty4000\widowpenalty4000
  \sfcode`\.=1000\relax}

\let\endthebibliography=\endlist

\sloppy
\parindent 1em
\leftmargin 2em
\leftmargini 2em
\leftmarginv .5em
\leftmarginvi .5em
\flushbottom
